/**
 * Moi (Luc Sorel, http://www.lucsorel.com/index.php?page=contact) reconnaît être l'auteur de ce code source. 
 * J'ai placé ce code source dans le domaine publique. Vous pouvez utiliser, modifier et distribuer le code 
 * source et les programmes exécutables basés sur ce code source. Veuillez toutefois prendre en considération 
 * les points suivants :
 * 
 * --- Décharge légale de garantie ---
 * Ce code source vous est présenté "en tant que tel" et sans garantie de performance ou d'intérêt commercial. 
 * L'auteur et / ou le distributeur ont pu faire des déclarations ) propos de ce code source. Ces déclarations 
 * n'ont pas valeur de garanties et ne doivent pas servir de fondements quant à l'utilisation tierce de ce code 
 * source.
 * 
 * Ce code source est mis à disposition sans aucune garantie implicite ou explicite. Étant donné la diversité 
 * des conditions contextuelles et matérielles sous lesquelles ce code source peut être utilisé, aucune garantie 
 * d'adéquation pour un usage spécifique n'est proposé. il est conseillé que l'utilisateur teste le code source 
 * consciencieusement avant de s'appuyer dessus. L'utilisateur prend l'entière responsabilité de l'utilisation 
 * de ce code source.
 */

package com.lucsorel.hesperis.client.ajax;

import org.enunes.gwt.mvp.client.EventBus;

import com.google.gwt.http.client.Request;
import com.google.gwt.http.client.RequestCallback;
import com.google.gwt.http.client.Response;
import com.lucsorel.hesperis.client.event.AfficherDeconnexionEvent;
import com.lucsorel.hesperis.client.event.MessageEvent;
import com.lucsorel.hesperis.client.modele.Erreur;
import com.lucsorel.hesperis.client.modele.Message;
import com.lucsorel.hesperis.client.modele.Utilisateur;
import com.lucsorel.hesperis.client.modele.Warning;

public class ConnexionRequestCallback implements RequestCallback
{
	static private ConnexionRequestCallback tCB_connexionCallback;

	final private EventBus iEB_eventBus;

	/**
	 * Le gestionnaire de retour de la requête de connexion connaît le bus d'événement
	 * @param pEB_eventBus
	 */
	private ConnexionRequestCallback( EventBus pEB_eventBus )
	{
		this.iEB_eventBus = pEB_eventBus;
	}

	static public ConnexionRequestCallback Instance( EventBus pEB_eventBus )
	{
		if( tCB_connexionCallback == null )
		{
			tCB_connexionCallback = new ConnexionRequestCallback( pEB_eventBus );
		}
		return tCB_connexionCallback;
	}

	@Override
	public void onError( Request request, Throwable pRE_exception )
	{
		iEB_eventBus.fireEvent( new MessageEvent(
				new Erreur( "Requête de connexion erronnée :\n" + pRE_exception.getMessage())
		) );
	}
	@Override
	public void onResponseReceived( Request request, Response pR_retourConnexion )
	{
		// gestion des erreurs
		String ls_texteReponse = pR_retourConnexion.getText();
		Message lM_message = null;
		Utilisateur lU_utilisateur = null;
		if( pR_retourConnexion.getStatusCode() != Response.SC_OK )
		{
			lM_message = new Erreur( "Erreur : " + pR_retourConnexion.getStatusText()
					+ "\n Code : " + pR_retourConnexion.getStatusCode()
					+ "\n Header : [" + pR_retourConnexion.getHeadersAsString() + "]" );
		}
		// récupération et traitement des données utilisateur
		else
		{
			lU_utilisateur = Utilisateur.Instance();
			lU_utilisateur.enrichirSelonJson( ls_texteReponse );
			if( ! lU_utilisateur.estValide() )
			{
				// création du message d'erreur en interprétant le retour de requête comme du JSON ou tel quel
				lM_message = Erreur.ErreurSelonJSON( ls_texteReponse );
				if( lM_message == null )
				{
					lM_message = new Warning( ls_texteReponse );
				}
			}
			else
			{
				lM_message = new Message( "Bienvenue <i>" + lU_utilisateur.getNom() + "</i>, vous allez être <b>connecté(e)</b> à Hespéris ! " );
			}
		}
		iEB_eventBus.fireEvent( new MessageEvent(lM_message) );

		if( lU_utilisateur.estValide() )
		{
			// Affichage de la déconnexion
			iEB_eventBus.fireEvent( new AfficherDeconnexionEvent(true) );
		}
	}
}
