/**
 * Moi (Luc Sorel, http://www.lucsorel.com/index.php?page=contact) reconnaît être l'auteur de ce code source. 
 * J'ai placé ce code source dans le domaine publique. Vous pouvez utiliser, modifier et distribuer le code 
 * source et les programmes exécutables basés sur ce code source. Veuillez toutefois prendre en considération 
 * les points suivants :
 * 
 * --- Décharge légale de garantie ---
 * Ce code source vous est présenté "en tant que tel" et sans garantie de performance ou d'intérêt commercial. 
 * L'auteur et / ou le distributeur ont pu faire des déclarations ) propos de ce code source. Ces déclarations 
 * n'ont pas valeur de garanties et ne doivent pas servir de fondements quant à l'utilisation tierce de ce code 
 * source.
 * 
 * Ce code source est mis à disposition sans aucune garantie implicite ou explicite. Étant donné la diversité 
 * des conditions contextuelles et matérielles sous lesquelles ce code source peut être utilisé, aucune garantie 
 * d'adéquation pour un usage spécifique n'est proposé. il est conseillé que l'utilisateur teste le code source 
 * consciencieusement avant de s'appuyer dessus. L'utilisateur prend l'entière responsabilité de l'utilisation 
 * de ce code source.
 */

package com.lucsorel.hesperis.client.presview;

import org.enunes.gwt.mvp.client.EventBus;
import org.enunes.gwt.mvp.client.presenter.BasePresenter;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.inject.Inject;
import com.lucsorel.hesperis.client.event.DemandeDeconnexionEvent;
import com.lucsorel.hesperis.client.modele.Utilisateur;
import com.lucsorel.hesperis.client.presview.IDeconnexion.Display;

public class DeconnexionPresenter extends BasePresenter<Display> implements IDeconnexion
{
	// présenteur gérant le module d'affichage des messages
	protected final IMessage iP_message;

	@Inject
	public DeconnexionPresenter( EventBus pEB_eventBus, Display pD_display,
			IMessage pP_message )
	{
		super( pEB_eventBus, pD_display );

		// récupération du panneau d'affichage des messages, enregistrements des gestionnaires et ajout à la vue
		iP_message = pP_message;
		iP_message.bind();
		display.ajouterMessageDisplay( iP_message.getDisplay() );
	}
	
	/**
	 * Crée les associations de base entre la vue et le présenteur
	 */
	@Override
	public void bind()
	{
		super.bind();
		
		/*****************************************************************************\
		 * Envoie au bus d'événements les signaux envoyés par les éléments de la vue *
		\*****************************************************************************/
		// Transforme un événement DOM de getDeconnexionClickHandlers() en l'événement métier DemandeDeconnexionEvent
		registerHandler( display.getDeconnexionClickHandlers().addClickHandler(
				new ClickHandler() {
					public void onClick( ClickEvent pE_ClickEvent )
					{
						eventBus.fireEvent( new DemandeDeconnexionEvent() );
					}
				}) );
	}

	/**
	 * Supprime les gestionnaires d'événement propres à ce Présenteur
	 * et aux Présenteurs inclus par celui-ci
	 */
	@Override
	public void unbind()
	{
		super.unbind();

		// Suppression des gestionnaires d'événements du présenteur MessagePresenter
		if( iP_message != null )
		{
			iP_message.unbind();
		}
	}
	public void afficherUtilisateur()
	{
		Utilisateur lU_utilisateur = Utilisateur.Instance();
		// l'utilisateur n'est pas valide, nettoyage de l'affichage et redirection sur l'interface de connexion
		if( ! lU_utilisateur.estValide() )
		{
			// nettoyage des informations utilisateur
			display.getLoginTexte().setText( "" );
			display.getNomTexte().setText( "" );
			
			// déconnexion délayée à 3 secondes
			eventBus.fireEvent( new DemandeDeconnexionEvent(3000) );
		}
		// l'utilisateur est valide : enrichissement de l'interface + message d'accueil
		else
		{
			display.getLoginTexte().setText( lU_utilisateur.getLogin() );
			display.getNomTexte().setText( lU_utilisateur.getNom() );

			// envoi du message par le bus d'événements
			String ls_message = "Bonjour <b>" + lU_utilisateur.getNom() + "</b>, bienvenue dans Hespéris";
			iP_message.getDisplay().getHtmlMessage().setStylePrimaryName( "message" );
			iP_message.getDisplay().getHtmlMessage().setHTML( ls_message );
		}
	}
}